@@ -111,7 +111,7 @@ exp_unpack (QofEntity * ent, gpointer user_data)
 	pi_buffer_t *pi_buf;
 	PQContext *context;
 	const QofParam * param;
-	size_t len;
+	size_t G_GNUC_UNUSED len;
 	gint size;
 	gchar * string;
 
