@@ -480,7 +480,7 @@ pilot_database_open (QofObject * obj, gpointer user_data)
 	if (p->db_pref_unpack)
 	{
 		gchar * creator;
-		gint pref_result = 0;
+		gint G_GNUC_UNUSED pref_result = 0;
 		/* Optionally, unpack preferences here */
 		pref_unpack = p->db_pref_unpack;
 		/* no entity available for the preferences, */
