@@ -220,7 +220,7 @@ select_cb (QofObject * obj, gpointer data)
 void
 qof_main_moderate_query (QofMainContext * context)
 {
-	GSList *date_param_list, *category_param_list;
+	GSList * G_GNUC_UNUSED date_param_list, * G_GNUC_UNUSED category_param_list;
 	gboolean all;
 
 	ENTER (" ");
@@ -473,7 +473,7 @@ void
 qof_mod_time (const gchar * date_time, QofMainContext * data)
 {
 	QofDate *qd;
-	gboolean all_year, all_month;
+	gboolean all_year, G_GNUC_UNUSED all_month;
 	gint adding_days;
 	gchar *info;
 
@@ -541,7 +541,6 @@ qof_mod_sql_file (const gchar * sql_file, QofMainContext * data)
 #endif
 	gchar *buf;
 	size_t n;
-	QofQuery *q;
 	regex_t *r;
 	gint reg_exp_check;
 	const gchar *fmt;
@@ -550,7 +549,6 @@ qof_mod_sql_file (const gchar * sql_file, QofMainContext * data)
 	ENTER (" ");
 	data->sql_file = g_strdup (sql_file);
 	n = 0;
-	q = NULL;
 	data->sql_list = NULL;
 	filehandle = fopen (sql_file, "r");
 	if (!filehandle)
